-- 世界地图item
Lua_WorldMapItem = class("Lua_WorldMapItem", Lua_DisplayObject);
function Lua_WorldMapItem:ctor(p)
    self:superCall("ctor", p, "WorldMapItem_skin");

end

function Lua_WorldMapItem:buildShowItem()
    self:superCall("buildShowItem");
    
    self.sceneImg:addClickFuntion(self,self.onMouseDownHandle);
    self.sceneImg:addMouseUpFuntion(self,self.onMouseUpHandle);
end

function Lua_WorldMapItem:updateLock()
	if self.data == nil then
		self.lockImg:setEnable(false);
		return;
	end

	local cData = Lua_SceneConfigData.getSceneConfig(self.data.sceneId);
	if DataCenter.roleData.level >= cData.minLv then
		self.sceneImg:setUrl(self.data.imgUrl);
		self.lockImg:setEnable(false);
	else
		local arr = string.split(self.data.imgUrl, ".");
		if arr:getSize() >= 2 then
			self.sceneImg:setUrl(arr[1] .. "h." .. arr[2]);
		end
		self.lockImg:setEnable(true);
	end
end

function Lua_WorldMapItem:isClickBox(x,y)
	local lx = self.x;
	local ly = self.y;
	local ox = math.abs(x - lx);
	if ox > 130 then
		return false;
	end
	local oy = math.abs(y - ly);
	if oy > 120 then
		return false;
	end
	return true;
end
function Lua_WorldMapItem:onMouseDownHandle()
	Lua_MsgUtil.callFunc("WORLD_MAP_DOWN");
end
function Lua_WorldMapItem:onMouseUpHandle()
	Lua_MsgUtil.callFunc("WORLD_MAP_UP");
end
function Lua_WorldMapItem:updateOwnScene()
	if self.data == nil then
		self.ownPoint:setEnable(false);
		return;
	end

	if self.data.sceneId == DataCenter.roleData.sceneId then	-- 已在该场景
		self:showOwnPoint(true);
	else
		self:showOwnPoint(false);
	end
end

function Lua_WorldMapItem:showOwnPoint(val)
	if val == true then
		if self.ownPoint == nil then
			self.ownPoint = UICreate.createUIAtlasImage(self.content, "map_atlas", "ui_map_jt_01", 0, 0, 0, 0);
			self.ownPoint:setDepth(5);
		end
		self.startTime = getTime();
		self:onMapPointEnterFrame();
		self:addTimer("map", 0.02, self, self.onMapPointEnterFrame);
	else
		if self.ownPoint ~= nil then
			self.ownPoint:dispose();
			self.ownPoint = nil;
		end
		Lua_CommonUtil.removeTimer(self, self.onMapPointEnterFrame);
	end
end

function Lua_WorldMapItem:onMapPointEnterFrame()
	local pt = (getTime() - self.startTime) * 5;
	self.ownPoint:setLocation(-4.5, 90 + 15 * math.sin(pt), 0);
end

function Lua_WorldMapItem:onItemClick(go)
	if self.data == nil then
		return;
	end
	if self.data.sceneId == DataCenter.roleData.sceneId then	-- 已在该场景
		OperateAlert.show(LanUtil.getValue(123300));
		return;
	end

	if DataCenter.roleData:isInCopy(true) == true then
		return;
	end

	local cData = Lua_SceneConfigData.getSceneConfig(self.data.sceneId);
	if DataCenter.roleData.level < cData.minLv then 
		OperateAlert.show(LanUtil.getValue(123311));
		return;
	-- elseif DataCenter.roleData.level > cData.maxLv then 
	-- 	OperateAlert.show(LanUtil.getValue(123312));
	-- 	return;
	end

	-- 传送
	local pos = self.data.fixed_pos;
	if pos ~= nil and #pos >= 3 then
		Lua_ProxyManager.getProxy("Lua_MapProxy"):sTransfer(self.data.sceneId, pos[1], pos[2], pos[3], 0);
		Lua_WindowUtil.openWin("Lua_MapWindow", WinParam.ACTION_CLOSE, nil);
		DataCenter.hook:stop(true);
	end
end

function Lua_WorldMapItem:setData(data)
	self.data = data;
	if data ~= nil then
		self.sceneImg:SetDimensions(0, 0);
		self.nameTxt.text = data.sceneName;
		self.descTxt.text = data.desTxt;
		
		local vRate = MainWinDefine.bgHeight / 720; -- 垂直
    	local hRate = MainWinDefine.bgWidth / 1280; -- 水平
    	if data.posX ~= nil and data.posY ~= nil then
			self:setLocation(data.posX * hRate, data.posY * vRate, 0);
		end
		
		if data.iconPosX ~= nil and data.iconPosY ~= nil then
			self.sceneImg:setLocation(data.iconPosX, data.iconPosY);
		end
		if data.namePosX ~= nil and data.namePosY ~= nil then
			self.nameTxt:setLocation(data.namePosX, data.namePosY);
			self.nameBg:setLocation(data.namePosX, data.namePosY);
		end
		if data.desPosX ~= nil and data.desPosY ~= nil then
			self.descTxt:setLocation(data.desPosX, data.desPosY);
			self.descBg:setLocation(data.desPosX, data.desPosY);
		end
		if data.ownPosX ~= nil and data.ownPosY ~= nil then
			self.ownPoint:setLocation(data.ownPosX, data.ownPosY);
		end

		if self.nameTxt.height > 104 then
			self.nameBg:SetDimensions(63, self.nameTxt.height + 40);
		else
			self.nameBg:SetDimensions(63, 194);
		end
	end

	self:updateLock();
	self:updateOwnScene();
end

function Lua_WorldMapItem:dispose()
    self:superCall("dispose");
end