-- 世界地图显示
checkRequire("Lua_WorldMapItem");
Lua_WorldMapPanel = class("Lua_WorldMapPanel", Lua_DisplayObject);
function Lua_WorldMapPanel:ctor(p)
    self:superCall("ctor", p, "WorldMapPanel_skin");
end

function Lua_WorldMapPanel:buildShowItem()
    self:superCall("buildShowItem");

    self._isClick = false;
    self.Image:SetDimensions(MainWinDefine.V_width, 720);

    self.uiPanel = self.mapContainer:AddComponent(typeof(UIPanel));  
    self.uiPanel.cullWhileDragging = false;
    self.uiPanel.softBorderPadding = false;
    self.uiPanel.clipSoftness = Vector2(0, 0);
    self.uiPanel.clipOffset = Vector2(0, 0);
    self.uiPanel.anchorOffset = false;
    self.uiPanel.widgetsAreStatic = false;
    self.uiPanel.baseClipRegion = Vector4(0, 0, MainWinDefine.V_width, 720);
    self.uiPanel.clipping = UIDrawCall.Clipping.SoftClip;

    self.imgWidth = 2560;
    self.imgHeight = 1440;
    local offsetX = (MainWinDefine.V_width - MainWinDefine.bgWidth) / 2;
    self.minX = -(self.imgWidth / 2 - 645 - offsetX);
    self.maxX = -self.minX;
    self.minY = -(self.imgHeight / 2 - 360);
    self.maxY = -self.minY;
    self.vRate = MainWinDefine.bgHeight / 720; -- 垂直
    self.hRate = MainWinDefine.bgWidth / MainWinDefine.V_width; -- 水平

    self:setItemPos(0,0);

    self.imgBg = UICreate.createImage(self.itemContainer, "/images/map/ui_map_bg_02.png", 0, 0, self.imgWidth, self.imgHeight);
    self.imgBg:setDepth(-1);
    self.imgBg.clickScale = false;
    self.imgBg:SetDimensions(self.imgWidth, self.imgHeight);
    self.imgBg:addClickFuntion(self,self.onMouseDownHandle);
    self.imgBg:addMouseUpFuntion(self,self.onMouseUpHandle);

	self.itemArr = Array();
	self:showWorldMap();

	self.uiPanel1 = self.otherContainer:AddComponent(typeof(UIPanel));  
    self.uiPanel1.cullWhileDragging = false;
    self.uiPanel1.softBorderPadding = false;

    self.uiPanel2 = self.btnContainer:AddComponent(typeof(UIPanel));  
    self.uiPanel2.cullWhileDragging = false;
    self.uiPanel2.softBorderPadding = false;

    self.closeBtn.clickScale = false;
    self.closeBtn:addClickFuntion(self, self.onCloseClick);
    
	self.sceneBtn.clickScale = false;
	self.sceneBtn:addClickFuntion(self, self.onSceneBtnClick);

	self:addLuaEvent("SCENE_CHANGE", self, self.onSceneChange);
	self:addLuaEvent("PLAYER_LEVEL_UP", self, self.onRoleLvUpdate);
	self:addLuaEvent("WORLD_MAP_DOWN", self, self.onMouseDownHandle);
	self:addLuaEvent("WORLD_MAP_UP", self, self.onMouseUpHandle);

	WindowMananger.getInstance():resetChildParent(self.content.transform);

	LuaUtil.updateWindowDepth(nil);
end

function Lua_WorldMapPanel:onMouseDownHandle(go,state)
    self:onPress(go,true);
end
function Lua_WorldMapPanel:onMouseUpHandle(go,state)
    self:onPress(go,false);
end
function Lua_WorldMapPanel:onPress(go, state)
    if self.setDispose == true then
        return;
    end
    if state == true then
        self.startMouseX = UnityEngine.Input.mousePosition.x;
		self.startMouseY = UnityEngine.Input.mousePosition.y;
		self.startPosX = self.itemPosX;
		self.startPosY = self.itemPosY;
        if self._isClick == false then
            self._isClick = true;
            Lua_CommonUtil.addTimer( "Lua_WorldMapPanel", 0.01, self, self.onEnterFrame);
        end
    else
    	local endX = UnityEngine.Input.mousePosition.x;
    	local endY = UnityEngine.Input.mousePosition.y;
        local dx = endX - self.startMouseX;
        local dy = endY - self.startMouseY;
        local co = math.abs(dx) + math.abs(dy);
        if co < 4 then
            self:checkClick();
        end
        if self._isClick == true then
            self._isClick = false;
            Lua_CommonUtil.removeTimer(self,self.onEnterFrame);
        end
    end
end
function Lua_WorldMapPanel:onEnterFrame()
	local dx = UnityEngine.Input.mousePosition.x - self.startMouseX;
	local dy = UnityEngine.Input.mousePosition.y - self.startMouseY;
	self:setItemPos(dx + self.startPosX, dy + self.startPosY);
end
function Lua_WorldMapPanel:setItemPos(x,y)
	if x < self.minX then
		self.itemPosX = self.minX;
	elseif x > self.maxX then
		self.itemPosX = self.maxX;
	else
		self.itemPosX = x;
	end
	if y < self.minY then
		self.itemPosY = self.minY;
	elseif y > self.maxY then
		self.itemPosY = self.maxY;
	else
		self.itemPosY = y;
	end
	
	-- self.itemContainer.transform.localPosition = Vector3(self.itemPosX,self.itemPosY, 0);
	LuaUtil.setObjPos(self.itemContainer, self.itemPosX,self.itemPosY, 0);
end
function Lua_WorldMapPanel:checkClick()
	local len = self.itemArr:getSize();
	local v = Vector3(UnityEngine.Input.mousePosition.x,UnityEngine.Input.mousePosition.y,0);
	local screenpos = UICamera.mainCamera:ScreenToWorldPoint(v);
	local mousePosition = self.itemContainer.transform:InverseTransformPoint(screenpos);
	for i = 1, len do
		if self.itemArr[i]:isClickBox(mousePosition.x,mousePosition.y) then
			self.itemArr[i]:onItemClick();
			return;
		end
	end
end
-- 等级变化
function Lua_WorldMapPanel:onRoleLvUpdate()
	if self.itemArr ~= nil then
		local len = self.itemArr:getSize();
		for i = 1, len do
			self.itemArr[i]:updateLock();
		end
	end
end

-- 切换场景
function Lua_WorldMapPanel:onSceneChange(o)
	if self.itemArr ~= nil then
		local len = self.itemArr:getSize();
		for i = 1, len do
			self.itemArr[i]:updateOwnScene();
		end
	end
end

function Lua_WorldMapPanel:onCloseClick()
	Lua_WindowUtil.openWin("Lua_MapWindow", WinParam.ACTION_CLOSE)
end

function Lua_WorldMapPanel:onSceneBtnClick(go)
	Lua_MsgUtil.callFunc("MAP_SHOW_SELECTTYPE", Lua_MapWindow.TYPE_SCENEMAP);
end

-- 显示世界地图
function Lua_WorldMapPanel:showWorldMap()
	local arr = DataCenter.mapWindowUtil.worldMapData;
	if arr ~= nil then
		local item;
		local len = arr:getSize();
		local num = self.itemArr:getSize() - len;
		while (num > 0) do
			item = self.itemArr:shift();
			item:dispose();
			num = num - 1;
		end

		while (num < 0) do
			item = Lua_WorldMapItem.new(self.itemContainer);
			self.itemArr:add(item);
			num = num + 1;
		end

		for i = 1, len do
			item = self.itemArr[i];
			item:setData(arr[i]);
			if arr[i].sceneId == DataCenter.roleData.sceneId then
				self:setItemPos(-1 * arr[i].posX * self.vRate, -1 * arr[i].posY * self.hRate);
			end
		end
	end
end
function Lua_WorldMapPanel:dispose()
	if self.itemArr ~= nil then
		local len = self.itemArr:getSize();
		for i = 1, len do
			self.itemArr[i]:dispose();
		end
		self.itemArr:clear();
		self.itemArr = nil;
	end
	Lua_CommonUtil.removeTimer(self,self.onEnterFrame);
    self:superCall("dispose");
end